// import React from 'react';
import React, { Suspense } from 'react';
import ReactDOM from 'react-dom/client';
import { RouterProvider, createBrowserRouter } from 'react-router-dom';
import '@/index.css';
import '@/styles/article-transition.css'; // 导入文章过渡动画样式
import { routes } from '@/routes/routes';
// 导入 i18n 配置
import '@/i18n';
// 导入 React Query
import { QueryClient, QueryClientProvider } from '@tanstack/react-query';
import { ReactQueryDevtools } from '@tanstack/react-query-devtools';
// 导入上下文提供者
import ResourceLoadingProvider from '@/context/ResourceLoadingContext';
// 导入开发者工具检测和保护
import setupDevToolsProtection from '@/utils/devtools-detector';
import disableDevShortcuts from '@/utils/disable-shortcuts';
// import initializeCodeProtection from '@/utils/code-protection';
// 导入安全服务
import { initializeSecurityServices } from '@/utils/security/enhanced-integration';
// 导入自定义右键菜单
import setupCustomContextMenu from '@/utils/custom-context-menu';
// 导入自定义右键菜单样式
import '@/styles/context-menu.css';

// 全局加载指示器组件
const GlobalLoadingFallback = () => (
    <div className="flex h-screen w-screen items-center justify-center">
        <div className="animate-pulse text-lg text-gray-600 dark:text-gray-300">
            正在加载应用...
        </div>
    </div>
);

// 创建 QueryClient 实例
const queryClient = new QueryClient({
    defaultOptions: {
        queries: {
            retry: 2, // 失败时重试2次
            staleTime: 5 * 60 * 1000, // 数据5分钟内视为新鲜
            cacheTime: 30 * 60 * 1000, // 缓存保留30分钟
            refetchOnWindowFocus: false, // 窗口聚焦时不自动重新获取
            suspense: true, // 启用Suspense模式
            onError: (error) => {
                // 全局错误处理
                console.error('Query error:', error);
            },
        },
        mutations: {
            onError: (error) => {
                console.error('Mutation error:', error);
            },
        },
    },
});

// 创建路由 - 使用更现代的数据路由API
const router = createBrowserRouter(routes);

// 定义需要排除滚动和进度条的路径
const excludePaths: string[] = [
    // 在这里添加不需要滚动到顶部或显示加载进度条的路径
    // 例如: '/no-scroll-path'
];

// 初始化应用
const initApp = () => {
    // 设置开发者工具保护（只在生产环境中生效）
    setupDevToolsProtection(false);

    // 禁用开发者工具快捷键（只在生产环境中生效）
    disableDevShortcuts(false);

    // 初始化代码混淆和保护（只在生产环境中生效）
    // initializeCodeProtection();

    // 初始化安全服务（只在生产环境中生效）
    // 这个会导致live2d模型无法正常显示
    // 所以如果需要使用live2d模型，需要关闭这个功能
    // initializeSecurityServices({ enableInDevMode: true });

    // 尝试预先请求剪贴板权限
    try {
        // 在用户首次交互时请求剪贴板读取权限
        const requestClipboardPermissions = () => {
            if (navigator.clipboard) {
                // 请求读取权限
                navigator.clipboard
                    .readText()
                    .then(() => console.log('剪贴板读取权限已获取'))
                    .catch((err) =>
                        console.warn('无法获取剪贴板读取权限:', err),
                    );

                // 请求写入权限
                navigator.clipboard
                    .writeText('')
                    .then(() => console.log('剪贴板写入权限已获取'))
                    .catch((err) =>
                        console.warn('无法获取剪贴板写入权限:', err),
                    );
            }

            // 获取权限后移除事件监听器
            document.removeEventListener('click', requestClipboardPermissions);
            document.removeEventListener(
                'keydown',
                requestClipboardPermissions,
            );
        };

        // 在用户首次交互时请求权限
        document.addEventListener('click', requestClipboardPermissions);
        document.addEventListener('keydown', requestClipboardPermissions);
    } catch (error) {
        console.warn('请求剪贴板权限失败:', error);
    }

    // 设置自定义右键菜单（允许常规右键功能，但禁止开发者工具选项）
    // 在所有环境中启用，但使用不同的配置
    try {
        // 检测当前主题模式
        const prefersDarkMode =
            window.matchMedia &&
            window.matchMedia('(prefers-color-scheme: dark)').matches;
        const isDarkMode =
            document.documentElement.classList.contains('dark') ||
            prefersDarkMode;

        // 根据环境确定debug设置
        const isDevEnv = process.env.NODE_ENV === 'development';

        // 初始化自定义右键菜单
        setupCustomContextMenu({
            debug: isDevEnv, // 开发环境显示调试信息
            darkMode: isDarkMode,
            enableInDevMode: true, // 确保在开发环境也启用
        });
    } catch (error) {
        console.error('[右键菜单] 初始化失败:', error);
    }

    // 渲染React应用
    const root = ReactDOM.createRoot(
        document.getElementById('root') as HTMLElement,
    );

    root.render(
        // <React.StrictMode>
        <QueryClientProvider client={queryClient}>
            {/* 资源加载监控上下文 - 不依赖RouterProvider */}
            <ResourceLoadingProvider
                autoStart={true}
                monitorInterval={150}
                debug={process.env.NODE_ENV === 'development'}
            >
                {/* 使用Suspense包裹RouterProvider，实现路由级别的懒加载 */}
                <Suspense fallback={<GlobalLoadingFallback />}>
                    {/* RouterProvider在最外层，以便其他上下文可以使用路由钩子 */}
                    <RouterProvider router={router} />
                </Suspense>

                {/* 只在开发环境中加载开发工具 */}
                {/* ReactQueryDevtools是React Query的开发工具 */}
                {process.env.NODE_ENV === 'development' && (
                    <ReactQueryDevtools initialIsOpen={false} />
                )}
            </ResourceLoadingProvider>
        </QueryClientProvider>,
        // </React.StrictMode>,
    );
};

// 添加DOM加载完成后的初始化逻辑，确保自定义右键菜单正确应用
document.addEventListener('DOMContentLoaded', () => {
    console.log('DOM已加载完成，初始化额外功能...');

    // 为防止可能的race condition，再次确保自定义右键菜单正确应用
    try {
        // 检测是否已初始化自定义右键菜单
        if (
            !document.getElementById('custom-context-menu') &&
            !document.querySelector('.custom-menu-item')
        ) {
            const prefersDarkMode =
                window.matchMedia &&
                window.matchMedia('(prefers-color-scheme: dark)').matches;
            const isDarkMode =
                document.documentElement.classList.contains('dark') ||
                prefersDarkMode;

            // 重新初始化自定义右键菜单
            setupCustomContextMenu({
                debug: process.env.NODE_ENV === 'development',
                darkMode: isDarkMode,
                enableInDevMode: true,
            });

            console.log('[右键菜单] 在DOM加载完成后重新初始化');
        }
    } catch (error) {
        console.error('[右键菜单] DOM加载后初始化失败:', error);
    }
});

// 应用初始化
initApp();
